@@ -1078,7 +1078,6 @@ public abstract class NumberFormat extends UFormat {
      * {@icu} Returns the list of Locales for which NumberFormats are available.
      * @return the available locales
      * @draft ICU 3.2 (retain)
-     * @provisional This API might change or be removed in a future release.
      */
     public static ULocale[] getAvailableULocales() {
         if (shim == null) {
@@ -1440,7 +1439,7 @@ public abstract class NumberFormat extends UFormat {
     static NumberFormat createInstance(ULocale desiredLocale, int choice) {
         // If the choice is PLURALCURRENCYSTYLE, the pattern is not a single
         // pattern, it is a pattern set, so we do not need to get them here.
-        // If the choice is ISOCURRENCYSTYLE, the pattern is the currrency
+        // If the choice is ISOCURRENCYSTYLE, the pattern is the currency
         // pattern in the locale but by replacing the single currency sign
         // with double currency sign.
         String pattern = getPattern(desiredLocale, choice);
@@ -1970,6 +1969,12 @@ public abstract class NumberFormat extends UFormat {
          */
         public static final Field COMPACT = new Field("compact");
 
+        /**
+         * Approximately sign. In ICU 70, this was categorized under the generic SIGN field.
+         * @draft ICU 71
+         */
+        public static final Field APPROXIMATELY_SIGN = new Field("approximately sign");
+
         /**
          * Constructs a new instance of NumberFormat.Field with the given field
          * name.
