@@ -106,8 +106,7 @@ public class Currency extends MeasureUnit {
      * but it always takes the form used in formal settings such as banking;
      * for example, "NT$" instead of "$" for TWD in zh-TW.
      *
-     * @draft ICU 67
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 67
      */
     public static final int FORMAL_SYMBOL_NAME = 4;
 
@@ -117,8 +116,7 @@ public class Currency extends MeasureUnit {
      * The variant symbol for a currency is an alternative symbol that is not
      * necessarily as widely used as the regular symbol.
      *
-     * @draft ICU 67
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 67
      */
     public static final int VARIANT_SYMBOL_NAME = 5;
 
@@ -280,7 +278,12 @@ public class Currency extends MeasureUnit {
     private static Currency loadCurrency(String key) {
         String region = key;
         CurrencyMetaInfo info = CurrencyMetaInfo.getInstance();
-        List<String> list = info.currencies(CurrencyFilter.onRegion(region));
+        // https://unicode-org.atlassian.net/browse/ICU-21997
+        // Prefer to use currencies that are legal tender.
+        List<String> list = info.currencies(CurrencyFilter.onRegion(region).withTender());
+        if (list.isEmpty()) {
+            list = info.currencies(CurrencyFilter.onRegion(region));
+        }
         if (!list.isEmpty()) {
             String code = list.get(0);
             return getInstance(code);
