@@ -59,23 +59,23 @@ public class DateTimeGeneratorTest extends TestFmwk {
     public void TestC() {
         String[][] tests = {
                 // These may change with actual data for Bhmm/bhmm skeletons
-                {"zh",     "Cm",      "Bh:mm"},
-                {"zh",     "CCm",     "Bhh:mm"},
-                {"zh",     "CCCm",    "BBBBh:mm"},
-                {"zh",     "CCCCm",   "BBBBhh:mm"},
-                {"zh",     "CCCCCm",  "BBBBBh:mm"},
-                {"zh",     "CCCCCCm", "BBBBBhh:mm"},
+                {"zh-TW",  "Cm",      "Bh:mm"},
+                {"zh-TW",  "CCm",     "Bhh:mm"},
+                {"zh-TW",  "CCCm",    "BBBBh:mm"},
+                {"zh-TW",  "CCCCm",   "BBBBhh:mm"},
+                {"zh-TW",  "CCCCCm",  "BBBBBh:mm"},
+                {"zh-TW",  "CCCCCCm", "BBBBBhh:mm"},
                 {"de",     "Cm",      "HH:mm"},
                 {"de",     "CCm",     "HH:mm"},
                 {"de",     "CCCm",    "HH:mm"},
                 {"de",     "CCCCm",   "HH:mm"},
-                {"en",     "Cm",      "h:mm a"},
-                {"en",     "CCm",     "hh:mm a"},
-                {"en",     "CCCm",    "h:mm aaaa"},
-                {"en",     "CCCCm",   "hh:mm aaaa"},
-                {"en",     "CCCCCm",  "h:mm aaaaa"},
-                {"en",     "CCCCCCm", "hh:mm aaaaa"},
-                {"en-BN",  "Cm",      "h:mm b"},
+                {"en",     "Cm",      "h:mm\u202Fa"},
+                {"en",     "CCm",     "hh:mm\u202Fa"},
+                {"en",     "CCCm",    "h:mm\u202Faaaa"},
+                {"en",     "CCCCm",   "hh:mm\u202Faaaa"},
+                {"en",     "CCCCCm",  "h:mm\u202Faaaaa"},
+                {"en",     "CCCCCCm", "hh:mm\u202Faaaaa"},
+                {"en-BN",  "Cm",      "h:mm\u202Fb"},
                 {"gu-IN",  "Cm",      "h:mm B"},
                 {"und-IN", "Cm",      "h:mm B"},
         };
@@ -163,7 +163,7 @@ public class DateTimeGeneratorTest extends TestFmwk {
         gen.addPattern("d'. von' MMMM", true, returnInfo);
         // the returnInfo is mostly useful for debugging problem cases
         format.applyPattern(gen.getBestPattern("MMMMdHmm"));
-        assertEquals("modified format: MMMdHmm", "14. von Oktober, 08:58", format.format(sampleDate));
+        assertEquals("modified format: MMMMdHmm", "14. von Oktober um 08:58", format.format(sampleDate));
 
         // get a pattern and modify it
         format = (SimpleDateFormat)DateFormat.getDateTimeInstance(DateFormat.FULL, DateFormat.FULL, locale);
@@ -196,15 +196,15 @@ public class DateTimeGeneratorTest extends TestFmwk {
                 {"yMMMMMd", "O 14, 1999"},  // narrow format
                 {"EEEEEMMMMMd", "T, O 14"},  // narrow format
                 {"MMMd", "Oct 14"},
-                {"MMMdhmm", "Oct 14, 6:58 AM"},
-                {"EMMMdhmms", "Thu, Oct 14, 6:58:59 AM"},
-                {"MMdhmm", "10/14, 6:58 AM"},
-                {"EEEEMMMdhmms", "Thursday, Oct 14, 6:58:59 AM"},
-                {"yyyyMMMddhhmmss", "Oct 14, 1999, 6:58:59 AM"}, // (fixed expected result per ticket 6872<-7180)
-                {"EyyyyMMMddhhmmss", "Thu, Oct 14, 1999, 6:58:59 AM"}, // (fixed expected result per ticket 6872<-7180)
-                {"hmm", "6:58 AM"},
-                {"hhmm", "6:58 AM"}, // (fixed expected result per ticket 6872<-7180)
-                {"hhmmVVVV", "6:58 AM GMT"}, // (fixed expected result per ticket 6872<-7180)
+                {"MMMdhmm", "Oct 14, 6:58\u202FAM"},
+                {"EMMMdhmms", "Thu, Oct 14, 6:58:59\u202FAM"},
+                {"MMdhmm", "10/14, 6:58\u202FAM"},
+                {"EEEEMMMdhmms", "Thursday, Oct 14, 6:58:59\u202FAM"},
+                {"yyyyMMMddhhmmss", "Oct 14, 1999, 6:58:59\u202FAM"}, // (fixed expected result per ticket 6872<-7180)
+                {"EyyyyMMMddhhmmss", "Thu, Oct 14, 1999, 6:58:59\u202FAM"}, // (fixed expected result per ticket 6872<-7180)
+                {"hmm", "6:58\u202FAM"},
+                {"hhmm", "6:58\u202FAM"}, // (fixed expected result per ticket 6872<-7180)
+                {"hhmmVVVV", "6:58\u202FAM GMT"}, // (fixed expected result per ticket 6872<-7180)
         };
         for (int i = 0; i < tests.length; ++i) {
             final String testSkeleton = tests[i][0];
@@ -377,14 +377,14 @@ public class DateTimeGeneratorTest extends TestFmwk {
         new String[] {"MMMd", "Jan 13"},
         new String[] {"MMMMd", "January 13"},
         new String[] {"yQQQ", "Q1 1999"},
-        new String[] {"hhmm", "11:58 PM"},
+        new String[] {"hhmm", "11:58\u202FPM"},
         new String[] {"HHmm", "23:58"},
-        new String[] {"jjmm", "11:58 PM"},
+        new String[] {"jjmm", "11:58\u202FPM"},
         new String[] {"mmss", "58:59"},
         new String[] {"yyyyMMMM", "January 1999"}, // (new item for testing 6872<-5702)
         new String[] {"MMMEd", "Wed, Jan 13"},
         new String[] {"Ed", "13 Wed"},
-        new String[] {"jmmssSSS", "11:58:59.123 PM"},
+        new String[] {"jmmssSSS", "11:58:59.123\u202FPM"},
         new String[] {"JJmm", "11:58"},
 
         new ULocale("en_US@calendar=japanese"), // (new locale for testing ticket 6872<-5702)
@@ -396,18 +396,18 @@ public class DateTimeGeneratorTest extends TestFmwk {
         new String[] {"MMMd", "Jan 13"},
         new String[] {"MMMMd", "January 13"},
         new String[] {"yQQQ", "Q1 11 Heisei"},
-        new String[] {"hhmm", "11:58 PM"},
+        new String[] {"hhmm", "11:58\u202FPM"},
         new String[] {"HHmm", "23:58"},
-        new String[] {"jjmm", "11:58 PM"},
+        new String[] {"jjmm", "11:58\u202FPM"},
         new String[] {"mmss", "58:59"},
         new String[] {"yyyyMMMM", "January 11 Heisei"},
         new String[] {"MMMEd", "Wed, Jan 13"},
         new String[] {"Ed", "13 Wed"},
-        new String[] {"jmmssSSS", "11:58:59.123 PM"},
+        new String[] {"jmmssSSS", "11:58:59.123\u202FPM"},
         new String[] {"JJmm", "11:58"},
 
         new ULocale("de_DE"),
-        new String[] {"yM", "1.1999"},
+        new String[] {"yM", "01/1999"},
         new String[] {"yMMM", "Jan. 1999"},
         new String[] {"yMd", "13.1.1999"},
         new String[] {"yMMMd", "13. Jan. 1999"},
@@ -415,7 +415,7 @@ public class DateTimeGeneratorTest extends TestFmwk {
         new String[] {"MMMd", "13. Jan."},
         new String[] {"MMMMd", "13. Januar"},
         new String[] {"yQQQ", "Q1 1999"},
-        new String[] {"hhmm", "11:58 PM"},
+        new String[] {"hhmm", "11:58\u202FPM"},
         new String[] {"HHmm", "23:58"},
         new String[] {"jjmm", "23:58"},
         new String[] {"mmss", "58:59"},
@@ -434,7 +434,7 @@ public class DateTimeGeneratorTest extends TestFmwk {
         new String[] {"MMMd", "13. tammik."},
         new String[] {"MMMMd", "13. tammikuuta"},
         new String[] {"yQQQ", "1. nelj. 1999"},
-        new String[] {"hhmm", "11.58 ip."},
+        new String[] {"hhmm", "11.58\u202Fip."},
         new String[] {"HHmm", "23.58"},
         new String[] {"jjmm", "23.58"},
         new String[] {"mmss", "58.59"},
@@ -453,7 +453,7 @@ public class DateTimeGeneratorTest extends TestFmwk {
         new String[] {"MMMd", "13 ene"},
         new String[] {"MMMMd", "13 de enero"},
         new String[] {"yQQQ", "T1 1999"},
-        new String[] {"hhmm", "11:58 p.\u00A0m."},
+        new String[] {"hhmm", "11:58\u202Fp.\u00A0m."},
         new String[] {"HHmm", "23:58"},
         new String[] {"jjmm", "23:58"},
         new String[] {"mmss", "58:59"},
@@ -512,13 +512,13 @@ public class DateTimeGeneratorTest extends TestFmwk {
         new String[] {"yQQQ", "1999\u5E74\u7B2C1\u5B63\u5EA6"},
         new String[] {"hhmm", "\u4E0B\u534811:58"},
         new String[] {"HHmm", "23:58"},
-        new String[] {"jjmm", "\u4E0B\u534811:58"},
+        new String[] {"jjmm", "23:58"},
         new String[] {"mmss", "58:59"},
         new String[] {"yyyyMMMM", "1999\u5E741\u6708"}, // (new item for testing 6872<-5702)
         new String[] {"MMMEd", "1\u670813\u65E5\u5468\u4E09"},
         new String[] {"Ed", "13\u65E5\u5468\u4E09"},
-        new String[] {"jmmssSSS", "\u4E0B\u534811:58:59.123"},
-        new String[] {"JJmm", "11:58"},
+        new String[] {"jmmssSSS", "23:58:59.123"},
+        new String[] {"JJmm", "23:58"},
 
         new ULocale("zh_TW@calendar=roc"), // (new locale for testing ticket 6872<-5702)
         new String[] {"yM", "\u6C11\u570B88/1"},
@@ -541,18 +541,18 @@ public class DateTimeGeneratorTest extends TestFmwk {
 
         new ULocale("ru"),
         new String[] {"yM", "01.1999"},
-        new String[] {"yMMM", "\u044F\u043D\u0432. 1999 \u0433."},
+        new String[] {"yMMM", "\u044F\u043D\u0432. 1999\u202F\u0433."},
         new String[] {"yMd", "13.01.1999"},
-        new String[] {"yMMMd", "13 \u044F\u043D\u0432. 1999 \u0433."},
+        new String[] {"yMMMd", "13 \u044F\u043D\u0432. 1999\u202F\u0433."},
         new String[] {"Md", "13.01"},
         new String[] {"MMMd", "13 \u044F\u043D\u0432."},
         new String[] {"MMMMd", "13 \u044F\u043D\u0432\u0430\u0440\u044F"},
-        new String[] {"yQQQ", "1-\u0439 \u043A\u0432. 1999 \u0433."},
-        new String[] {"hhmm", "11:58 PM"},
+        new String[] {"yQQQ", "1-\u0439 \u043A\u0432. 1999\u202F\u0433."},
+        new String[] {"hhmm", "11:58\u202FPM"},
         new String[] {"HHmm", "23:58"},
         new String[] {"jjmm", "23:58"},
         new String[] {"mmss", "58:59"},
-        new String[] {"yyyyMMMM", "\u044F\u043D\u0432\u0430\u0440\u044C 1999 \u0433."},
+        new String[] {"yyyyMMMM", "\u044F\u043D\u0432\u0430\u0440\u044C 1999\u202F\u0433."},
         new String[] {"MMMEd", "\u0441\u0440, 13 \u044F\u043D\u0432."},
         new String[] {"Ed", "\u0441\u0440, 13"},
         new String[] {"jmmssSSS", "23:58:59,123"},
@@ -569,13 +569,13 @@ public class DateTimeGeneratorTest extends TestFmwk {
         new String[] {"yQQQ", "1998\u620A\u5BC5\u5E74\u7B2C\u56DB\u5B63\u5EA6"},
         new String[] {"hhmm", "\u4E0B\u534811:58"},
         new String[] {"HHmm", "23:58"},
-        new String[] {"jjmm", "\u4E0B\u534811:58"},
+        new String[] {"jjmm", "23:58"},
         new String[] {"mmss", "58:59"},
         new String[] {"yyyyMMMM", "1998\u620A\u5BC5\u5E74\u5341\u4E00\u6708"},
         new String[] {"MMMEd", "\u5341\u4E00\u670826\u65E5\u5468\u4E09"},
         new String[] {"Ed", "26\u65E5\u5468\u4E09"},
-        new String[] {"jmmssSSS", "\u4E0B\u534811:58:59.123"},
-        new String[] {"JJmm", "11:58"},
+        new String[] {"jmmssSSS", "23:58:59.123"},
+        new String[] {"JJmm", "23:58"},
 
         new ULocale("ja_JP_TRADITIONAL"),
         // TODO: This is different in C++ and Java.
@@ -1382,18 +1382,18 @@ public class DateTimeGeneratorTest extends TestFmwk {
     @Test
     public void TestOptions() {
         final TestOptionsItem[] testOptionsData = {
-                new TestOptionsItem( "en", "Hmm",  "HH:mm",   DateTimePatternGenerator.MATCH_NO_OPTIONS        ),
-                new TestOptionsItem( "en", "HHmm", "HH:mm",   DateTimePatternGenerator.MATCH_NO_OPTIONS        ),
-                new TestOptionsItem( "en", "hhmm", "h:mm a",  DateTimePatternGenerator.MATCH_NO_OPTIONS        ),
-                new TestOptionsItem( "en", "Hmm",  "HH:mm",   DateTimePatternGenerator.MATCH_HOUR_FIELD_LENGTH ),
-                new TestOptionsItem( "en", "HHmm", "HH:mm",   DateTimePatternGenerator.MATCH_HOUR_FIELD_LENGTH ),
-                new TestOptionsItem( "en", "hhmm", "hh:mm a", DateTimePatternGenerator.MATCH_HOUR_FIELD_LENGTH ),
-                new TestOptionsItem( "da", "Hmm",  "HH.mm",   DateTimePatternGenerator.MATCH_NO_OPTIONS        ),
-                new TestOptionsItem( "da", "HHmm", "HH.mm",   DateTimePatternGenerator.MATCH_NO_OPTIONS        ),
-                new TestOptionsItem( "da", "hhmm", "h.mm a",  DateTimePatternGenerator.MATCH_NO_OPTIONS        ),
-                new TestOptionsItem( "da", "Hmm",  "H.mm",    DateTimePatternGenerator.MATCH_HOUR_FIELD_LENGTH ),
-                new TestOptionsItem( "da", "HHmm", "HH.mm",   DateTimePatternGenerator.MATCH_HOUR_FIELD_LENGTH ),
-                new TestOptionsItem( "da", "hhmm", "hh.mm a", DateTimePatternGenerator.MATCH_HOUR_FIELD_LENGTH ),
+                new TestOptionsItem( "en", "Hmm",  "HH:mm",        DateTimePatternGenerator.MATCH_NO_OPTIONS        ),
+                new TestOptionsItem( "en", "HHmm", "HH:mm",        DateTimePatternGenerator.MATCH_NO_OPTIONS        ),
+                new TestOptionsItem( "en", "hhmm", "h:mm\u202Fa",  DateTimePatternGenerator.MATCH_NO_OPTIONS        ),
+                new TestOptionsItem( "en", "Hmm",  "HH:mm",        DateTimePatternGenerator.MATCH_HOUR_FIELD_LENGTH ),
+                new TestOptionsItem( "en", "HHmm", "HH:mm",        DateTimePatternGenerator.MATCH_HOUR_FIELD_LENGTH ),
+                new TestOptionsItem( "en", "hhmm", "hh:mm\u202Fa", DateTimePatternGenerator.MATCH_HOUR_FIELD_LENGTH ),
+                new TestOptionsItem( "da", "Hmm",  "HH.mm",        DateTimePatternGenerator.MATCH_NO_OPTIONS        ),
+                new TestOptionsItem( "da", "HHmm", "HH.mm",        DateTimePatternGenerator.MATCH_NO_OPTIONS        ),
+                new TestOptionsItem( "da", "hhmm", "h.mm\u202Fa",  DateTimePatternGenerator.MATCH_NO_OPTIONS        ),
+                new TestOptionsItem( "da", "Hmm",  "H.mm",         DateTimePatternGenerator.MATCH_HOUR_FIELD_LENGTH ),
+                new TestOptionsItem( "da", "HHmm", "HH.mm",        DateTimePatternGenerator.MATCH_HOUR_FIELD_LENGTH ),
+                new TestOptionsItem( "da", "hhmm", "hh.mm\u202Fa", DateTimePatternGenerator.MATCH_HOUR_FIELD_LENGTH ),
                 //
                 new TestOptionsItem( "en",                   "yyyy",  "yyyy",  DateTimePatternGenerator.MATCH_NO_OPTIONS ),
                 new TestOptionsItem( "en",                   "YYYY",  "YYYY",  DateTimePatternGenerator.MATCH_NO_OPTIONS ),
@@ -1407,8 +1407,8 @@ public class DateTimeGeneratorTest extends TestFmwk {
                 new TestOptionsItem( "en@calendar=chinese",  "Gy",    "r(U)",     DateTimePatternGenerator.MATCH_NO_OPTIONS ),
                 new TestOptionsItem( "en@calendar=chinese",  "GU",    "r(U)",     DateTimePatternGenerator.MATCH_NO_OPTIONS ),
                 new TestOptionsItem( "en@calendar=chinese",  "ULLL",  "MMM U",    DateTimePatternGenerator.MATCH_NO_OPTIONS ),
-                new TestOptionsItem( "en@calendar=chinese",  "yMMM",  "MMM r(U)", DateTimePatternGenerator.MATCH_NO_OPTIONS ),
-                new TestOptionsItem( "en@calendar=chinese",  "GUMMM", "MMM r(U)", DateTimePatternGenerator.MATCH_NO_OPTIONS ),
+                new TestOptionsItem( "en@calendar=chinese",  "yMMM",  "MMM r",    DateTimePatternGenerator.MATCH_NO_OPTIONS ),
+                new TestOptionsItem( "en@calendar=chinese",  "GUMMM", "MMM r",    DateTimePatternGenerator.MATCH_NO_OPTIONS ),
                 new TestOptionsItem( "zh@calendar=chinese",  "yyyy",  "rU\u5E74",    DateTimePatternGenerator.MATCH_NO_OPTIONS ),
                 new TestOptionsItem( "zh@calendar=chinese",  "YYYY",  "YY\u5E74",    DateTimePatternGenerator.MATCH_NO_OPTIONS ), // not a good result, want r(Y) or r(U)
                 new TestOptionsItem( "zh@calendar=chinese",  "U",     "rU\u5E74",    DateTimePatternGenerator.MATCH_NO_OPTIONS ),
@@ -1735,7 +1735,7 @@ public class DateTimeGeneratorTest extends TestFmwk {
             // to ar_SA, which has a region.
             {"ars", "h a", "h:mm a", "HOUR_CYCLE_12"},
             // en_NH is interesting because NH is a depregated region code.
-            {"en_NH", "h a", "h:mm a", "HOUR_CYCLE_12"},
+            {"en_NH", "h\u202Fa", "h:mm\u202Fa", "HOUR_CYCLE_12"},
             // ch_ZH is a typo (should be zh_CN), but we should fail gracefully.
             {"cn_ZH", "HH", "HH:mm", "HOUR_CYCLE_23"}, // Desired & now actual behavior (does this fix ICU-20653?)
             // a non-BCP47 locale without a country code should not fail
@@ -1793,4 +1793,264 @@ public class DateTimeGeneratorTest extends TestFmwk {
             }
         }
     }
+    
+    @Test
+    public void testBestPattern() {
+        // generic test for DateTimePatternGenerator::getBestPattern() that can be used to test multiple
+        // bugs in the resource data
+        String[] testCases = {
+            // ICU-21650: (See the "week day" section of https://www.unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table
+            // for a full explanation of why this is the desired behavior)
+            // if the user asks for E, the minimum field length is 3, but if he asks for c or e, it's 1
+            "en_US",      "E",           "ccc",
+            "en_US",      "c",           "c",
+            "en_US",      "e",           "c",
+            "en_US",      "EE",          "ccc",
+            "en_US",      "cc",          "cc",
+            "en_US",      "ee",          "cc",
+            "en_US",      "EEE",         "ccc",
+            "en_US",      "ccc",         "ccc",
+            "en_US",      "eee",         "ccc",
+            // and if the user asked for c or e and the field length is 1 or 2, the output pattern should contain
+            // e instead of E (e supports numeric abbreviations; E doesn't)
+            "en_US",      "yMEd",        "EEE, M/d/y",
+            "en_US",      "yMcd",        "e, M/d/y",
+            "en_US",      "yMed",        "e, M/d/y",
+            "en_US",      "yMMEEdd",     "EEE, MM/dd/y",
+            "en_US",      "yMMccdd",     "ee, MM/dd/y",
+            "en_US",      "yMMeedd",     "ee, MM/dd/y",
+            "en_US",      "yMMMEd",      "EEE, MMM d, y",
+            "en_US",      "yMMMcccd",    "EEE, MMM d, y",
+            "en_US",      "yMMMeeed",    "EEE, MMM d, y",
+            "en_US",      "yMMMMEEEEd",  "EEEE, MMMM d, y",
+            "en_US",      "yMMMMccccd",  "EEEE, MMMM d, y",
+            "en_US",      "yMMMMeeeed",  "EEEE, MMMM d, y",
+
+            // ICU-20992: Bad patterns for missing fields
+            "ckb_IR",     "mmSSS",       "mm:ss٫SSS",
+            "ckb_IR",     "BSSS",        "SSS ├'Dayperiod': B┤",
+
+            // ICU-21873: Missing aliased values
+            "en_001@calendar=islamic", "Ehm", "EEE h:mm\u202Fa",
+        };
+
+        for (int i = 0; i < testCases.length; i += 3) {
+            String localeID = testCases[i];
+            ULocale locale = new ULocale(localeID);
+            String skeleton = testCases[i + 1];
+            String expectedPattern = testCases[i + 2];
+            String actualPattern = null;
+        
+            if (!skeleton.equals("full")) {
+                DateTimePatternGenerator dtpg = DateTimePatternGenerator.getInstance(locale);
+                actualPattern = dtpg.getBestPattern(skeleton);
+            } else {
+                DateFormat df = DateFormat.getDateInstance(DateFormat.FULL, locale);
+                SimpleDateFormat sdf = (SimpleDateFormat)df;
+            
+                if (sdf != null) {
+                    actualPattern = sdf.toPattern();
+                }
+            }
+        
+            assertEquals("Wrong result for test case " + localeID + "/" + skeleton, expectedPattern, actualPattern);
+        }
+    }
+
+    // Test for ICU-21202: Make sure DateTimePatternGenerator supplies an era field for year formats using the
+    // Buddhist and Japanese calendars for all English-speaking locales.
+    @Test
+    public void testEras() {
+        String[] localeIDs = {
+            "en_US@calendar=japanese",
+            "en_GB@calendar=japanese",
+            "en_150@calendar=japanese",
+            "en_001@calendar=japanese",
+            "en@calendar=japanese",
+            "en_US@calendar=buddhist",
+            "en_GB@calendar=buddhist",
+            "en_150@calendar=buddhist",
+            "en_001@calendar=buddhist",
+            "en@calendar=buddhist",
+        };
+
+        for (String localeID : localeIDs) {
+            DateTimePatternGenerator dtpg = DateTimePatternGenerator.getInstance(new Locale(localeID));
+            String pattern = dtpg.getBestPattern("y");
+
+            if (pattern.indexOf('G') < 0) {
+                errln("missing era field for locale " + localeID);
+            }
+        }
+    }
+
+    private final static int NUM_DATE_TIME_PATTERNS = 4;
+
+    private final class DTPLocaleAndResults {
+        public String localeID;
+        public String[] expectPat;
+        // Simple constructor
+        public DTPLocaleAndResults(String locID, String[] exPat) {
+            localeID = locID;
+            expectPat = exPat;
+        }
+    }
+
+    @Test
+    public void testDateTimePatterns() {
+        String[] skeletons = {
+            "yMMMMEEEEdjmm", // full date, short time
+            "yMMMMdjmm",     // long date, short time
+            "yMMMdjmm",      // medium date, short time
+            "yMdjmm",        // short date, short time
+        };
+        // The following tests some locales in which there are differences between the
+        // DateTimePatterns of various length styles.
+        final DTPLocaleAndResults[] localeAndResults = {
+            new DTPLocaleAndResults( "en", new String[]{ // long != medium
+                                           "EEEE, MMMM d, y 'at' h:mm\u202Fa",
+                                           "MMMM d, y 'at' h:mm\u202Fa",
+                                           "MMM d, y, h:mm\u202Fa",
+                                           "M/d/y, h:mm\u202Fa" } ),
+            new DTPLocaleAndResults( "fr", new String[]{ // medium != short
+                                           "EEEE d MMMM y 'à' HH:mm",
+                                           "d MMMM y 'à' HH:mm",
+                                           "d MMM y, HH:mm",
+                                           "dd/MM/y HH:mm" } ),
+            new DTPLocaleAndResults( "ha", new String[]{
+                                           "EEEE d MMMM, y 'da' HH:mm",
+                                           "d MMMM, y 'da' HH:mm",
+                                           "d MMM, y, HH:mm",
+                                           "y-MM-dd, HH:mm" } ),
+        };
+
+        String[] enDTPatterns = {
+            "{1} 'at' {0}",
+            "{1} 'at' {0}",
+            "{1}, {0}",
+            "{1}, {0}",
+        };
+        String[] modDTPatterns = {
+            "{1} _0_ {0}",
+            "{1} _1_ {0}",
+            "{1} _2_ {0}",
+            "{1} _3_ {0}",
+        };
+        final DTPLocaleAndResults enModResults =
+            new DTPLocaleAndResults( "en", new String[]{
+                                            "EEEE, MMMM d, y _0_ h:mm\u202Fa",
+                                            "MMMM d, y _1_ h:mm\u202Fa",
+                                            "MMM d, y _2_ h:mm\u202Fa",
+                                            "M/d/y _3_ h:mm\u202Fa" } );
+
+        // Test various locales with standard data
+        DateTimePatternGenerator dtpg;
+        for (DTPLocaleAndResults localeAndResultItem: localeAndResults) {
+            dtpg = DateTimePatternGenerator.getInstance(new Locale(localeAndResultItem.localeID));
+            doDTPatternTest(dtpg, skeletons, localeAndResultItem);
+        }
+        // Test getting and modifying date-time combining patterns
+        dtpg = DateTimePatternGenerator.getInstance(ULocale.ENGLISH);
+        // Test style out of range
+        String dtFormat0 = "";
+        boolean gotException = false;
+        try {
+            dtFormat0 = dtpg.getDateTimeFormat(DateFormat.NONE);
+        } catch(IllegalArgumentException e) {
+            gotException = true;
+        }
+        if (!gotException) {
+            errln("ERROR: getDateTimeFormat with invalid style, expected IllegalArgumentException but got format \""
+                    + dtFormat0 + "\"");
+        }
+        // Test normal getting and setting
+        for (int patStyle = 0; patStyle < NUM_DATE_TIME_PATTERNS; patStyle++) {
+            String dtFormat1 = dtpg.getDateTimeFormat(patStyle);
+            if (!dtFormat1.equals(enDTPatterns[patStyle])) {
+                errln("ERROR: getDateTimeFormat for en before mod, style " + patStyle +
+                    ", expect \"" + enDTPatterns[patStyle] + "\", get \"" + dtFormat1 + "\"");
+            }
+            dtpg.setDateTimeFormat(patStyle, modDTPatterns[patStyle]);
+            String dtFormat2 = dtpg.getDateTimeFormat(patStyle);
+            if (!dtFormat2.equals(modDTPatterns[patStyle])) {
+                errln("ERROR: getDateTimeFormat for en after  mod, style " + patStyle +
+                    ", expect \"" + modDTPatterns[patStyle] + "\", get \"" + dtFormat2 + "\"");
+            }
+        }
+        // Test result of setting
+        doDTPatternTest(dtpg, skeletons, enModResults);
+        // Test old get/set functions
+        String dtFormat3 = dtpg.getDateTimeFormat();
+        if (!dtFormat3.equals(modDTPatterns[DateFormat.MEDIUM])) {
+            errln("ERROR: old getDateTimeFormat for en before mod, expect \"" +
+                    modDTPatterns[DateFormat.MEDIUM] + "\", get \"" + dtFormat3 + "\"");
+        }
+        dtpg.setDateTimeFormat(modDTPatterns[DateFormat.SHORT]); // set all dateTimePatterns to the short format
+        for (int patStyle = 0; patStyle < NUM_DATE_TIME_PATTERNS; patStyle++) {
+            String dtFormat4 = dtpg.getDateTimeFormat(patStyle);
+            if (!dtFormat4.equals(modDTPatterns[DateFormat.SHORT])) {
+                errln("ERROR: getDateTimeFormat for en after second mod, style " + patStyle +
+                    ", expect \"" + modDTPatterns[DateFormat.SHORT] + "\", get \"" + dtFormat4 + "\"");
+            }
+        }
+    }
+
+    private void doDTPatternTest(DateTimePatternGenerator dtpg, String[] skeletons, DTPLocaleAndResults localeAndResultItem) {
+        for (int patStyle = 0; patStyle < NUM_DATE_TIME_PATTERNS; patStyle++) {
+            String getPat = dtpg.getBestPattern(skeletons[patStyle]);
+            if (!getPat.equals(localeAndResultItem.expectPat[patStyle])) {
+                errln("ERROR: getBestPattern locale " + localeAndResultItem.localeID + ", style " + patStyle +
+                    ", expect \"" + localeAndResultItem.expectPat[patStyle] + "\", get \"" + getPat + "\"");
+            }
+        }
+    }
+
+    // Test for ICU-21839: Make sure ISO8601 patterns/symbols are inherited from Gregorian
+    @Test
+    public void testISO8601() {
+        String[] localeIDs = {
+            "de-AT-u-ca-iso8601",
+            "de-CH-u-ca-iso8601",
+        };
+        String skeleton = "jms";
+
+        for (String localeID : localeIDs) {
+            ULocale uloc = ULocale.forLanguageTag(localeID);
+
+            DateTimePatternGenerator dtpg = DateTimePatternGenerator.getInstance(uloc);
+            String pattern = dtpg.getBestPattern(skeleton);
+            if (pattern.contains("├") || pattern.contains("Minute")) {
+                errln("ERROR: locale " + localeID + ", skeleton " + skeleton + ", bad pattern: " + pattern);
+            }
+
+            DateFormat df = DateFormat.getTimeInstance(DateFormat.MEDIUM, uloc);
+            String format = df.format(new Date());
+            if (format.contains("├") || format.contains("Minute")) {
+                errln("ERROR: locale " + localeID + ", MEDIUM, bad format: " + format);
+            }
+        }
+    }
+    
+    @Test
+    public void testRegionOverride() {
+        String[][] testCases = {
+            { "en_US",           "h:mm\u202fa", "HOUR_CYCLE_12" },
+            { "en_GB",           "HH:mm",       "HOUR_CYCLE_23" },
+            { "en_US@rg=GBZZZZ", "HH:mm",       "HOUR_CYCLE_23" },
+            { "en_US@hours=h23", "HH:mm",       "HOUR_CYCLE_23" },
+        };
+
+        for (String[] testCase : testCases) {
+            String localeID = testCase[0];
+            String expectedPattern = testCase[1];
+            String expectedHourCycle = testCase[2];
+        
+            DateTimePatternGenerator dtpg = DateTimePatternGenerator.getInstance(new ULocale(localeID));
+            String actualHourCycle = dtpg.getDefaultHourCycle().toString();
+            String actualPattern = dtpg.getBestPattern("jmm");
+            
+            assertEquals("Wrong hour cycle", expectedHourCycle, actualHourCycle);
+            assertEquals("Wrong pattern", expectedPattern, actualPattern);
+        }
+    }
 }
