@@ -23,6 +23,7 @@ import org.junit.runner.RunWith;
 import org.junit.runners.JUnit4;
 
 import com.ibm.icu.dev.test.TestFmwk;
+import com.ibm.icu.impl.number.DecimalQuantity;
 import com.ibm.icu.text.DecimalFormat;
 import com.ibm.icu.text.DecimalFormatSymbols;
 import com.ibm.icu.text.MessageFormat;
@@ -228,10 +229,10 @@ public class PluralFormatUnitTest extends TestFmwk {
             logln(localeName + "\ttoString\t" + rules.toString());
             Set<String> keywords = rules.getKeywords();
             for (String keyword : keywords) {
-                Collection<Double> list = rules.getSamples(keyword);
+                Collection<DecimalQuantity> list = rules.getDecimalQuantitySamples(keyword);
                 if (list.size() == 0) {
                     // if there aren't any integer samples, get the decimal ones.
-                    list = rules.getSamples(keyword, SampleType.DECIMAL);
+                    list = rules.getDecimalQuantitySamples(keyword, SampleType.DECIMAL);
                 }
 
                 if (list == null || list.size() == 0) {
