@@ -252,64 +252,64 @@ public class RelativeDateTimeFormatterTest extends TestFmwk {
     @Test
     public void TestRelativeDateWithQuantityNarrow() {
         Object[][] data = {
-                {0.0, Direction.NEXT, RelativeUnit.SECONDS, "in 0 sec."},
-                {0.5, Direction.NEXT, RelativeUnit.SECONDS, "in 0.5 sec."},
+                {0.0, Direction.NEXT, RelativeUnit.SECONDS, "in 0s"},
+                {0.5, Direction.NEXT, RelativeUnit.SECONDS, "in 0.5s"},
 
-                {1.0, Direction.NEXT, RelativeUnit.SECONDS, "in 1 sec."},
-                {2.0, Direction.NEXT, RelativeUnit.SECONDS, "in 2 sec."},
-                {0.0, Direction.NEXT, RelativeUnit.MINUTES, "in 0 min."},
-                {0.5, Direction.NEXT, RelativeUnit.MINUTES, "in 0.5 min."},
-                {1.0, Direction.NEXT, RelativeUnit.MINUTES, "in 1 min."},
-                {2.0, Direction.NEXT, RelativeUnit.MINUTES, "in 2 min."},
-                {0.0, Direction.NEXT, RelativeUnit.HOURS, "in 0 hr."},
-                {0.5, Direction.NEXT, RelativeUnit.HOURS, "in 0.5 hr."},
-                {1.0, Direction.NEXT, RelativeUnit.HOURS, "in 1 hr."},
-                {2.0, Direction.NEXT, RelativeUnit.HOURS, "in 2 hr."},
-                {0.0, Direction.NEXT, RelativeUnit.DAYS, "in 0 days"},
-                {0.5, Direction.NEXT, RelativeUnit.DAYS, "in 0.5 days"},
-                {1.0, Direction.NEXT, RelativeUnit.DAYS, "in 1 day"},
-                {2.0, Direction.NEXT, RelativeUnit.DAYS, "in 2 days"},
-                {0.0, Direction.NEXT, RelativeUnit.WEEKS, "in 0 wk."},
-                {0.5, Direction.NEXT, RelativeUnit.WEEKS, "in 0.5 wk."},
-                {1.0, Direction.NEXT, RelativeUnit.WEEKS, "in 1 wk."},
-                {2.0, Direction.NEXT, RelativeUnit.WEEKS, "in 2 wk."},
-                {0.0, Direction.NEXT, RelativeUnit.MONTHS, "in 0 mo."},
-                {0.5, Direction.NEXT, RelativeUnit.MONTHS, "in 0.5 mo."},
-                {1.0, Direction.NEXT, RelativeUnit.MONTHS, "in 1 mo."},
-                {2.0, Direction.NEXT, RelativeUnit.MONTHS, "in 2 mo."},
-                {0.0, Direction.NEXT, RelativeUnit.YEARS, "in 0 yr."},
-                {0.5, Direction.NEXT, RelativeUnit.YEARS, "in 0.5 yr."},
-                {1.0, Direction.NEXT, RelativeUnit.YEARS, "in 1 yr."},
-                {2.0, Direction.NEXT, RelativeUnit.YEARS, "in 2 yr."},
+                {1.0, Direction.NEXT, RelativeUnit.SECONDS, "in 1s"},
+                {2.0, Direction.NEXT, RelativeUnit.SECONDS, "in 2s"},
+                {0.0, Direction.NEXT, RelativeUnit.MINUTES, "in 0m"},
+                {0.5, Direction.NEXT, RelativeUnit.MINUTES, "in 0.5m"},
+                {1.0, Direction.NEXT, RelativeUnit.MINUTES, "in 1m"},
+                {2.0, Direction.NEXT, RelativeUnit.MINUTES, "in 2m"},
+                {0.0, Direction.NEXT, RelativeUnit.HOURS, "in 0h"},
+                {0.5, Direction.NEXT, RelativeUnit.HOURS, "in 0.5h"},
+                {1.0, Direction.NEXT, RelativeUnit.HOURS, "in 1h"},
+                {2.0, Direction.NEXT, RelativeUnit.HOURS, "in 2h"},
+                {0.0, Direction.NEXT, RelativeUnit.DAYS, "in 0d"},
+                {0.5, Direction.NEXT, RelativeUnit.DAYS, "in 0.5d"},
+                {1.0, Direction.NEXT, RelativeUnit.DAYS, "in 1d"},
+                {2.0, Direction.NEXT, RelativeUnit.DAYS, "in 2d"},
+                {0.0, Direction.NEXT, RelativeUnit.WEEKS, "in 0w"},
+                {0.5, Direction.NEXT, RelativeUnit.WEEKS, "in 0.5w"},
+                {1.0, Direction.NEXT, RelativeUnit.WEEKS, "in 1w"},
+                {2.0, Direction.NEXT, RelativeUnit.WEEKS, "in 2w"},
+                {0.0, Direction.NEXT, RelativeUnit.MONTHS, "in 0mo"},
+                {0.5, Direction.NEXT, RelativeUnit.MONTHS, "in 0.5mo"},
+                {1.0, Direction.NEXT, RelativeUnit.MONTHS, "in 1mo"},
+                {2.0, Direction.NEXT, RelativeUnit.MONTHS, "in 2mo"},
+                {0.0, Direction.NEXT, RelativeUnit.YEARS, "in 0y"},
+                {0.5, Direction.NEXT, RelativeUnit.YEARS, "in 0.5y"},
+                {1.0, Direction.NEXT, RelativeUnit.YEARS, "in 1y"},
+                {2.0, Direction.NEXT, RelativeUnit.YEARS, "in 2y"},
 
-                {0.0, Direction.LAST, RelativeUnit.SECONDS, "0 sec. ago"},
-                {0.5, Direction.LAST, RelativeUnit.SECONDS, "0.5 sec. ago"},
-                {1.0, Direction.LAST, RelativeUnit.SECONDS, "1 sec. ago"},
-                {2.0, Direction.LAST, RelativeUnit.SECONDS, "2 sec. ago"},
-                {0.0, Direction.LAST, RelativeUnit.MINUTES, "0 min. ago"},
-                {0.5, Direction.LAST, RelativeUnit.MINUTES, "0.5 min. ago"},
-                {1.0, Direction.LAST, RelativeUnit.MINUTES, "1 min. ago"},
-                {2.0, Direction.LAST, RelativeUnit.MINUTES, "2 min. ago"},
-                {0.0, Direction.LAST, RelativeUnit.HOURS, "0 hr. ago"},
-                {0.5, Direction.LAST, RelativeUnit.HOURS, "0.5 hr. ago"},
-                {1.0, Direction.LAST, RelativeUnit.HOURS, "1 hr. ago"},
-                {2.0, Direction.LAST, RelativeUnit.HOURS, "2 hr. ago"},
-                {0.0, Direction.LAST, RelativeUnit.DAYS, "0 days ago"},
-                {0.5, Direction.LAST, RelativeUnit.DAYS, "0.5 days ago"},
-                {1.0, Direction.LAST, RelativeUnit.DAYS, "1 day ago"},
-                {2.0, Direction.LAST, RelativeUnit.DAYS, "2 days ago"},
-                {0.0, Direction.LAST, RelativeUnit.WEEKS, "0 wk. ago"},
-                {0.5, Direction.LAST, RelativeUnit.WEEKS, "0.5 wk. ago"},
-                {1.0, Direction.LAST, RelativeUnit.WEEKS, "1 wk. ago"},
-                {2.0, Direction.LAST, RelativeUnit.WEEKS, "2 wk. ago"},
-                {0.0, Direction.LAST, RelativeUnit.MONTHS, "0 mo. ago"},
-                {0.5, Direction.LAST, RelativeUnit.MONTHS, "0.5 mo. ago"},
-                {1.0, Direction.LAST, RelativeUnit.MONTHS, "1 mo. ago"},
-                {2.0, Direction.LAST, RelativeUnit.MONTHS, "2 mo. ago"},
-                {0.0, Direction.LAST, RelativeUnit.YEARS, "0 yr. ago"},
-                {0.5, Direction.LAST, RelativeUnit.YEARS, "0.5 yr. ago"},
-                {1.0, Direction.LAST, RelativeUnit.YEARS, "1 yr. ago"},
-                {2.0, Direction.LAST, RelativeUnit.YEARS, "2 yr. ago"},
+                {0.0, Direction.LAST, RelativeUnit.SECONDS, "0s ago"},
+                {0.5, Direction.LAST, RelativeUnit.SECONDS, "0.5s ago"},
+                {1.0, Direction.LAST, RelativeUnit.SECONDS, "1s ago"},
+                {2.0, Direction.LAST, RelativeUnit.SECONDS, "2s ago"},
+                {0.0, Direction.LAST, RelativeUnit.MINUTES, "0m ago"},
+                {0.5, Direction.LAST, RelativeUnit.MINUTES, "0.5m ago"},
+                {1.0, Direction.LAST, RelativeUnit.MINUTES, "1m ago"},
+                {2.0, Direction.LAST, RelativeUnit.MINUTES, "2m ago"},
+                {0.0, Direction.LAST, RelativeUnit.HOURS, "0h ago"},
+                {0.5, Direction.LAST, RelativeUnit.HOURS, "0.5h ago"},
+                {1.0, Direction.LAST, RelativeUnit.HOURS, "1h ago"},
+                {2.0, Direction.LAST, RelativeUnit.HOURS, "2h ago"},
+                {0.0, Direction.LAST, RelativeUnit.DAYS, "0d ago"},
+                {0.5, Direction.LAST, RelativeUnit.DAYS, "0.5d ago"},
+                {1.0, Direction.LAST, RelativeUnit.DAYS, "1d ago"},
+                {2.0, Direction.LAST, RelativeUnit.DAYS, "2d ago"},
+                {0.0, Direction.LAST, RelativeUnit.WEEKS, "0w ago"},
+                {0.5, Direction.LAST, RelativeUnit.WEEKS, "0.5w ago"},
+                {1.0, Direction.LAST, RelativeUnit.WEEKS, "1w ago"},
+                {2.0, Direction.LAST, RelativeUnit.WEEKS, "2w ago"},
+                {0.0, Direction.LAST, RelativeUnit.MONTHS, "0mo ago"},
+                {0.5, Direction.LAST, RelativeUnit.MONTHS, "0.5mo ago"},
+                {1.0, Direction.LAST, RelativeUnit.MONTHS, "1mo ago"},
+                {2.0, Direction.LAST, RelativeUnit.MONTHS, "2mo ago"},
+                {0.0, Direction.LAST, RelativeUnit.YEARS, "0y ago"},
+                {0.5, Direction.LAST, RelativeUnit.YEARS, "0.5y ago"},
+                {1.0, Direction.LAST, RelativeUnit.YEARS, "1y ago"},
+                {2.0, Direction.LAST, RelativeUnit.YEARS, "2y ago"},
 
         };
         RelativeDateTimeFormatter fmt = RelativeDateTimeFormatter.getInstance(
@@ -634,10 +634,10 @@ public class RelativeDateTimeFormatterTest extends TestFmwk {
                 {Direction.THIS, AbsoluteUnit.SUNDAY, "this Su"},
 
                 {Direction.PLAIN, AbsoluteUnit.DAY, "day"},
-                {Direction.PLAIN, AbsoluteUnit.WEEK, "wk."},
-                {Direction.PLAIN, AbsoluteUnit.MONTH, "mo."},
-                {Direction.PLAIN, AbsoluteUnit.QUARTER, "qtr."},
-                {Direction.PLAIN, AbsoluteUnit.YEAR, "yr."},
+                {Direction.PLAIN, AbsoluteUnit.WEEK, "wk"},
+                {Direction.PLAIN, AbsoluteUnit.MONTH, "mo"},
+                {Direction.PLAIN, AbsoluteUnit.QUARTER, "qtr"},
+                {Direction.PLAIN, AbsoluteUnit.YEAR, "yr"},
                 {Direction.PLAIN, AbsoluteUnit.MONDAY, "M"},
                 {Direction.PLAIN, AbsoluteUnit.TUESDAY, "T"},
                 {Direction.PLAIN, AbsoluteUnit.WEDNESDAY, "W"},
