@@ -2,8 +2,7 @@
 // License & terms of use: http://www.unicode.org/copyright.html
 package com.ibm.icu.dev.test.number;
 
-import static org.junit.Assert.assertEquals;
-
+import java.math.BigDecimal;
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -13,6 +12,7 @@ import java.util.Set;
 
 import org.junit.Test;
 
+import com.ibm.icu.dev.test.TestFmwk;
 import com.ibm.icu.dev.test.format.FormattedValueTest;
 import com.ibm.icu.impl.ICUData;
 import com.ibm.icu.impl.ICUResourceBundle;
@@ -40,9 +40,10 @@ import com.ibm.icu.util.UResourceBundle;
  * @author sffc
  *
  */
-public class NumberRangeFormatterTest {
+public class NumberRangeFormatterTest extends TestFmwk {
 
     private static final Currency USD = Currency.getInstance("USD");
+    private static final Currency CHF = Currency.getInstance("CHF");
     private static final Currency GBP = Currency.getInstance("GBP");
     private static final Currency PTE = Currency.getInstance("PTE");
 
@@ -132,14 +133,14 @@ public class NumberRangeFormatterTest {
                 .numberFormatterBoth(NumberFormatter.with().unit(MeasureUnit.FAHRENHEIT).unitWidth(UnitWidth.FULL_NAME)),
             new ULocale("fr-FR"),
             "1–5\u00A0degrés Fahrenheit",
-            "≈5\u00A0degrés Fahrenheit",
-            "≈5\u00A0degrés Fahrenheit",
+            "≃5\u00A0degrés Fahrenheit",
+            "≃5\u00A0degrés Fahrenheit",
             "0–3\u00A0degrés Fahrenheit",
-            "≈0\u00A0degré Fahrenheit",
+            "≃0\u00A0degré Fahrenheit",
             "3–3\u202F000\u00A0degrés Fahrenheit",
             "3\u202F000–5\u202F000\u00A0degrés Fahrenheit",
             "4\u202F999–5\u202F001\u00A0degrés Fahrenheit",
-            "≈5\u202F000\u00A0degrés Fahrenheit",
+            "≃5\u202F000\u00A0degrés Fahrenheit",
             "5\u202F000–5\u202F000\u202F000\u00A0degrés Fahrenheit");
 
         assertFormatRange(
@@ -147,14 +148,14 @@ public class NumberRangeFormatterTest {
             NumberRangeFormatter.with(),
             new ULocale("ja"),
             "1～5",
-            "約 5",
-            "約 5",
+            "約5",
+            "約5",
             "0～3",
-            "約 0",
+            "約0",
             "3～3,000",
             "3,000～5,000",
             "4,999～5,001",
-            "約 5,000",
+            "約5,000",
             "5,000～5,000,000");
 
         assertFormatRange(
@@ -663,6 +664,44 @@ public class NumberRangeFormatterTest {
             "5,000–5,000,000");
     }
 
+    @Test
+    public void test21397_UnsetNull() {
+        assertFormatRange(
+            "Unset identity fallback",
+            NumberRangeFormatter.with()
+                .identityFallback(RangeIdentityFallback.RANGE)
+                .identityFallback(null),
+            new ULocale("en-us"),
+            "1–5",
+            "~5",
+            "~5",
+            "0–3",
+            "~0",
+            "3–3,000",
+            "3,000–5,000",
+            "4,999–5,001",
+            "~5,000",
+            "5,000–5,000,000");
+    }
+
+    @Test
+    public void testNaNInfinity() {
+        LocalizedNumberRangeFormatter lnf = NumberRangeFormatter.withLocale(ULocale.ENGLISH);
+        FormattedNumberRange result1 = lnf.formatRange(Double.NEGATIVE_INFINITY, 0);
+        FormattedNumberRange result2 = lnf.formatRange(0, Double.POSITIVE_INFINITY);
+        FormattedNumberRange result3 = lnf.formatRange(Double.NEGATIVE_INFINITY, Double.POSITIVE_INFINITY);
+        FormattedNumberRange result4 = lnf.formatRange(Double.NaN, 0);
+        FormattedNumberRange result5 = lnf.formatRange(0, Double.NaN);
+        FormattedNumberRange result6 = lnf.formatRange(Double.NaN, Double.NaN);
+
+        assertEquals("0 - inf", "-∞ – 0", result1.toString());
+        assertEquals("-inf - 0", "0–∞", result2.toString());
+        assertEquals("-inf - inf", "-∞ – ∞", result3.toString());
+        assertEquals("NaN - 0", "NaN–0", result4.toString());
+        assertEquals("0 - NaN", "0–NaN", result5.toString());
+        assertEquals("NaN - NaN", "~NaN", result6.toString());
+    }
+
     @Test
     public void testPlurals() {
         // Locale sl has interesting plural forms:
@@ -735,8 +774,10 @@ public class NumberRangeFormatterTest {
                     5000,
                     expectedString);
             Object[][] expectedFieldPositions = new Object[][]{
+                    {NumberRangeFormatter.SpanField.NUMBER_RANGE_SPAN, 0, 2, 0},
                     {NumberFormat.Field.INTEGER, 0, 1},
                     {NumberFormat.Field.COMPACT, 1, 2},
+                    {NumberRangeFormatter.SpanField.NUMBER_RANGE_SPAN, 5, 7, 1},
                     {NumberFormat.Field.INTEGER, 5, 6},
                     {NumberFormat.Field.COMPACT, 6, 7},
                     {NumberFormat.Field.MEASURE_UNIT, 8, 9}};
@@ -753,14 +794,32 @@ public class NumberRangeFormatterTest {
                     98765432,
                     expectedString);
             Object[][] expectedFieldPositions = new Object[][]{
+                    {NumberRangeFormatter.SpanField.NUMBER_RANGE_SPAN, 0, 10, 0},
                     {NumberFormat.Field.GROUPING_SEPARATOR, 2, 3},
                     {NumberFormat.Field.GROUPING_SEPARATOR, 6, 7},
                     {NumberFormat.Field.INTEGER, 0, 10},
+                    {NumberRangeFormatter.SpanField.NUMBER_RANGE_SPAN, 11, 21, 1},
                     {NumberFormat.Field.GROUPING_SEPARATOR, 13, 14},
                     {NumberFormat.Field.GROUPING_SEPARATOR, 17, 18},
                     {NumberFormat.Field.INTEGER, 11, 21}};
             FormattedValueTest.checkFormattedValue(message, fmtd, expectedString, expectedFieldPositions);
         }
+
+        {
+            String message = "Field position with approximately sign";
+            String expectedString = "~-100";
+            FormattedNumberRange fmtd = assertFormattedRangeEquals(
+                    message,
+                    NumberRangeFormatter.withLocale(ULocale.US),
+                    -100,
+                    -100,
+                    expectedString);
+            Object[][] expectedFieldPositions = new Object[][]{
+                    {NumberFormat.Field.APPROXIMATELY_SIGN, 0, 1},
+                    {NumberFormat.Field.SIGN, 1, 2},
+                    {NumberFormat.Field.INTEGER, 2, 5}};
+            FormattedValueTest.checkFormattedValue(message, fmtd, expectedString, expectedFieldPositions);
+        }
     }
 
     static final String[] allNSNames = NumberingSystem.getAvailableNames();
@@ -780,7 +839,8 @@ public class NumberRangeFormatterTest {
                 }
                 UResource.Table nsTable = value.getTable();
                 for (int j = 0; nsTable.getKeyAndValue(j, key, value); ++j) {
-                    if (!key.contentEquals("miscPatterns")) {
+                    if (!key.contentEquals("miscPatterns") || value.getType()!=UResourceBundle.TABLE) {
+                        // now miscPatterns might have an alias; for now skip alias instead of following
                         continue;
                     }
                     UResource.Table miscTable = value.getTable();
@@ -830,6 +890,129 @@ public class NumberRangeFormatterTest {
         }
     }
 
+    @Test
+    public void test21684_Performance() {
+        LocalizedNumberRangeFormatter lnf = NumberRangeFormatter.withLocale(ULocale.ENGLISH);
+        // The following two lines of code should finish quickly.
+        lnf.formatRange(new BigDecimal("-1e99999"), new BigDecimal("0"));
+        lnf.formatRange(new BigDecimal("0"), new BigDecimal("1e99999"));
+    }
+
+    @Test
+    public void test21358_SignPosition() {
+        // de-CH has currency pattern "¤ #,##0.00;¤-#,##0.00"
+        assertFormatRange(
+            "Approximately sign position with spacing from pattern",
+            NumberRangeFormatter.with()
+                .numberFormatterBoth(NumberFormatter.with().unit(CHF)),
+            ULocale.forLanguageTag("de-CH"),
+            "CHF 1.00–5.00",
+            "CHF≈5.00",
+            "CHF≈5.00",
+            "CHF 0.00–3.00",
+            "CHF≈0.00",
+            "CHF 3.00–3’000.00",
+            "CHF 3’000.00–5’000.00",
+            "CHF 4’999.00–5’001.00",
+            "CHF≈5’000.00",
+            "CHF 5’000.00–5’000’000.00");
+
+        // TODO(ICU-21420): Move the sign to the inside of the number
+        assertFormatRange(
+            "Approximately sign position with currency spacing",
+            NumberRangeFormatter.with()
+                .numberFormatterBoth(NumberFormatter.with().unit(CHF)),
+            ULocale.forLanguageTag("en-US"),
+            "CHF 1.00–5.00",
+            "~CHF 5.00",
+            "~CHF 5.00",
+            "CHF 0.00–3.00",
+            "~CHF 0.00",
+            "CHF 3.00–3,000.00",
+            "CHF 3,000.00–5,000.00",
+            "CHF 4,999.00–5,001.00",
+            "~CHF 5,000.00",
+            "CHF 5,000.00–5,000,000.00");
+
+        {
+            LocalizedNumberRangeFormatter lnrf = NumberRangeFormatter
+                .withLocale(ULocale.forLanguageTag("de-CH"));
+            String actual = lnrf.formatRange(-2, 3).toString();
+            assertEquals("Negative to positive range", "-2 – 3", actual);
+        }
+
+        {
+            LocalizedNumberRangeFormatter lnrf = NumberRangeFormatter
+                .withLocale(ULocale.forLanguageTag("de-CH"))
+                .numberFormatterBoth(NumberFormatter.forSkeleton("%"));
+            String actual = lnrf.formatRange(-2, 3).toString();
+            assertEquals("Negative to positive percent", "-2% – 3%", actual);
+        }
+
+        {
+            // TODO(CLDR-14111): Add spacing between range separator and sign
+            LocalizedNumberRangeFormatter lnrf = NumberRangeFormatter
+                .withLocale(ULocale.forLanguageTag("de-CH"));
+            String actual = lnrf.formatRange(2, -3).toString();
+            assertEquals("Positive to negative range", "2–-3", actual);
+        }
+
+        {
+            LocalizedNumberRangeFormatter lnrf = NumberRangeFormatter
+                .withLocale(ULocale.forLanguageTag("de-CH"))
+                .numberFormatterBoth(NumberFormatter.forSkeleton("%"));
+            String actual = lnrf.formatRange(2, -3).toString();
+            assertEquals("Positive to negative percent", "2% – -3%", actual);
+        }
+    }
+
+    @Test
+    public void testCreateLNRFFromNumberingSystemInSkeleton() {
+        {
+            LocalizedNumberRangeFormatter lnrf = NumberRangeFormatter
+                .withLocale(ULocale.forLanguageTag("en"))
+                .numberFormatterBoth(NumberFormatter.forSkeleton(
+                    ".### rounding-mode-half-up"));
+            String actual = lnrf.formatRange(1, 234).toString();
+            assertEquals("default numbering system", "1–234", actual);
+        }
+        {
+            LocalizedNumberRangeFormatter lnrf = NumberRangeFormatter
+                .withLocale(ULocale.forLanguageTag("th"))
+                .numberFormatterBoth(NumberFormatter.forSkeleton(
+                    ".### rounding-mode-half-up numbering-system/thai"));
+            String actual = lnrf.formatRange(1, 234).toString();
+            assertEquals("Thai numbering system", "๑-๒๓๔", actual);
+        }
+        {
+            LocalizedNumberRangeFormatter lnrf = NumberRangeFormatter
+                .withLocale(ULocale.forLanguageTag("en"))
+                .numberFormatterBoth(NumberFormatter.forSkeleton(
+                    ".### rounding-mode-half-up numbering-system/arab"));
+            String actual = lnrf.formatRange(1, 234).toString();
+            assertEquals("Arabic numbering system", "١–٢٣٤", actual);
+        }
+        {
+            LocalizedNumberRangeFormatter lnrf = NumberRangeFormatter
+                .withLocale(ULocale.forLanguageTag("en"))
+                .numberFormatterFirst(NumberFormatter.forSkeleton("numbering-system/arab"))
+                .numberFormatterSecond(NumberFormatter.forSkeleton("numbering-system/arab"));
+            String actual = lnrf.formatRange(1, 234).toString();
+            assertEquals("Double Arabic numbering system", "١–٢٣٤", actual);
+        }
+    }
+
+    @Test(expected = IllegalArgumentException.class)
+    public void testCreateLNRFFromNumberingSystemInSkeletonError() {
+        LocalizedNumberRangeFormatter lnrf = NumberRangeFormatter
+            .withLocale(ULocale.forLanguageTag("en"))
+            .numberFormatterFirst(NumberFormatter.forSkeleton("numbering-system/arab"))
+            .numberFormatterSecond(NumberFormatter.forSkeleton("numbering-system/latn"));
+        // Note: The error is not thrown until `formatRange` because this is where the
+        // formatter object gets built.
+        lnrf.formatRange(1, 234);
+    }
+
     static void assertFormatRange(
             String message,
             UnlocalizedNumberRangeFormatter f,
