@@ -1,5 +1,5 @@
 // © 2016 and later: Unicode, Inc. and others.
-// License & terms of use: http://www.unicode.org/copyright.html#License
+// License & terms of use: http://www.unicode.org/copyright.html
 /**
 *******************************************************************************
 * Copyright (C) 2002-2007, International Business Machines Corporation and    *
@@ -9,10 +9,19 @@
 
 package com.ibm.icu.dev.test.perf;
 
-import com.ibm.icu.text.*;
-import java.util.*;
-import java.io.*;
+import java.io.BufferedReader;
+import java.io.FileInputStream;
+import java.io.IOException;
+import java.io.InputStreamReader;
+import java.util.ArrayList;
+import java.util.Comparator;
+
 import com.ibm.icu.impl.LocaleUtility;
+import com.ibm.icu.text.CollationElementIterator;
+import com.ibm.icu.text.CollationKey;
+import com.ibm.icu.text.Normalizer;
+import com.ibm.icu.text.NumberFormat;
+import com.ibm.icu.text.RuleBasedCollator;
 
 public class CollationPerformanceTest {
     static final String usageString = 
@@ -325,7 +334,7 @@ public class CollationPerformanceTest {
         //int opt2 = 0;
         
         for(;;) {   //not really a loop, just allows "break" to work, to simplify 
-                    //inadvertantly running more than one test through here
+                    //inadvertently running more than one test through here
             if(opt_strcmp) {
                 int r = 0;
                 startTime = System.currentTimeMillis();
@@ -1261,4 +1270,4 @@ public class CollationPerformanceTest {
             this.value = value;
         }
     }
-}
\ No newline at end of file
+}
